@@ -125,7 +125,7 @@
 #' # load the ggplot2-library.
 #' library(ggplot2)
 #' set_theme(base = theme_classic())
-#' sjp.frq(efc$e42dep)
+#' plot_frq(efc$e42dep)
 #'
 #' # adjust value labels
 #' set_theme(
@@ -143,7 +143,7 @@
 #'   base = theme_classic(), axis.linecolor = "grey50",
 #'   axis.textcolor = "#6699cc"
 #' )
-#' sjp.frq(efc$e42dep)}
+#' plot_frq(efc$e42dep)}
 #'
 #' @import ggplot2
 #' @importFrom scales brewer_pal grey_pal
@@ -560,7 +560,7 @@ sj.setGeomColors <- function(plot,
   # ---------------------------------------------------------
   # check for themr options
   # ---------------------------------------------------------
-  if (!is.null(geom.colors) && geom.colors == "themr") {
+  if (!is.null(geom.colors) && geom.colors[1] == "themr") {
     return(plot)
   }
 
