@@ -13,9 +13,9 @@
 #' @inheritParams sjp.fa
 #' @inheritParams sjp.pca
 #' @inheritParams sjt.pca
-#' @inheritParams sjt.frq
+#' @inheritParams tab_model
+#' @inheritParams tab_df
 #' @inheritParams sjt.xtab
-#' @inheritParams sjt.df
 #' @inheritParams sjp.grpfrq
 #' @inheritParams sjt.corr
 #'
@@ -33,8 +33,6 @@
 #' @note This method for factor analysis relies on the functions
 #'       \code{\link[psych]{fa}} and \code{\link[psych]{fa.parallel}} from the psych package.
 #'
-#' @details See 'Details' in \code{\link{sjt.frq}}.
-#'
 #'
 #' @examples
 #' \dontrun{
@@ -60,19 +58,18 @@ sjt.fa <- function(data,
                    method = c("ml", "minres", "wls", "gls", "pa", "minchi", "minrank"),
                    nmbr.fctr = NULL,
                    fctr.load.tlrn = 0.1,
-                    title = "Factor Analysis",
-                    var.labels = NULL,
-                    wrap.labels = 40,
-                    show.cronb = TRUE,
-                    show.comm = FALSE,
-                    altr.row.col = FALSE,
-                    digits = 2,
-                    CSS = NULL,
-                    encoding = NULL,
-                    file = NULL,
-                    use.viewer = TRUE,
-                    no.output = FALSE,
-                    remove.spaces = TRUE) {
+                   title = "Factor Analysis",
+                   var.labels = NULL,
+                   wrap.labels = 40,
+                   show.cronb = TRUE,
+                   show.comm = FALSE,
+                   alternate.rows = FALSE,
+                   digits = 2,
+                   CSS = NULL,
+                   encoding = NULL,
+                   file = NULL,
+                   use.viewer = TRUE,
+                   remove.spaces = TRUE) {
   # -------------------------------------
   # check encoding
   # -------------------------------------
@@ -262,7 +259,7 @@ sjt.fa <- function(data,
     for (n in seq_len(length(unique(itemloadings)))) {
       # calculate cronbach's alpha for those cases that all have the
       # highest loading on the same factor
-      cbv <- c(cbv, sjstats::cronb(stats::na.omit(dataframe[, which(itemloadings == n)])))
+      cbv <- c(cbv, performance::cronbachs_alpha(stats::na.omit(dataframe[, which(itemloadings == n)])))
     }
     # cbv now contains the factor numbers and the related alpha values
     # for each "factor dimension scale"
@@ -336,7 +333,7 @@ sjt.fa <- function(data,
     # default row string for alternative row colors
     arcstring <- ""
     # if we have alternating row colors, set css
-    if (altr.row.col) arcstring <- ifelse(sjmisc::is_even(i), " arc", "")
+    if (alternate.rows) arcstring <- ifelse(sjmisc::is_even(i), " arc", "")
     # write tr-tag with class-attributes
     page.content <- paste0(page.content, "  <tr>\n")
     # print first table cell
@@ -461,7 +458,6 @@ sjt.fa <- function(data,
       factor.index = factorindex,
       removed.items = removableItems,
       file = file,
-      show = !no.output,
       viewer = use.viewer
     )
   )
