@@ -38,7 +38,7 @@
 #' @param max.len Numeric, indicates how many values and value labels per variable
 #'   are shown. Useful for variables with many different values, where the output
 #'   can be truncated.
-#' @param verbose,hide.progress Logical, if \code{TRUE}, a progress bar is displayed
+#' @param verbose Logical, if \code{TRUE}, a progress bar is displayed
 #'   while creating the output.
 #'
 #' @inheritParams tab_df
@@ -97,7 +97,6 @@ view_df <- function(x,
                     max.len = 15,
                     sort.by.name = FALSE,
                     wrap.labels = 50,
-                    hide.progress = FALSE,
                     verbose = TRUE,
                     CSS = NULL,
                     encoding = NULL,
@@ -105,13 +104,6 @@ view_df <- function(x,
                     use.viewer = TRUE,
                     remove.spaces = TRUE) {
 
-  ## TODO remove hide.progress later
-
-  if (!missing(hide.progress)) {
-    message("`hide.progress` is deprecated. Please use `verbose` instead.")
-    verbose <- !hide.progress
-  }
-
   # check encoding
   encoding <- get.encoding(encoding, x)
 
@@ -390,7 +382,7 @@ view_df <- function(x,
       if (is.list(x[[index]]))
         valstring <- "<span class=\"omit\">&lt;list&gt;</span>"
       else
-        valstring <- frq.value(index, x, df.val)
+        valstring <- frq.value(index, x, df.val, max.len = max.len)
 
       page.content <-
         paste0(page.content,
@@ -406,7 +398,7 @@ view_df <- function(x,
       if (is.list(x[[index]]))
         valstring <- "<span class=\"omit\">&lt;list&gt;</span>"
       else
-        valstring <- frq.value(index, x, df.val, as.prc = TRUE)
+        valstring <- frq.value(index, x, df.val, as.prc = TRUE, max.len = max.len)
 
       page.content <-
         paste0(page.content,
@@ -422,7 +414,7 @@ view_df <- function(x,
       if (is.list(x[[index]]))
         valstring <- "<span class=\"omit\">&lt;list&gt;</span>"
       else
-        valstring <- frq.value(index, x, df.val, weights)
+        valstring <- frq.value(index, x, df.val, weights, max.len = max.len)
 
       page.content <-
         paste0(page.content,
@@ -438,7 +430,7 @@ view_df <- function(x,
       if (is.list(x[[index]]))
         valstring <- "<span class=\"omit\">&lt;list&gt;</span>"
       else
-        valstring <- frq.value(index, x, df.val, weights, as.prc = TRUE)
+        valstring <- frq.value(index, x, df.val, weights, as.prc = TRUE, max.len = max.len)
 
       page.content <-
         paste0(page.content,
@@ -498,7 +490,7 @@ view_df <- function(x,
 
 #' @importFrom stats xtabs na.pass
 #' @importFrom sjmisc is_empty
-frq.value <- function(index, x, df.val, weights, as.prc = FALSE) {
+frq.value <- function(index, x, df.val, weights, as.prc = FALSE, max.len) {
   valstring <- ""
   # check if we have a valid index
   if (index <= ncol(x) && !is.null(df.val[[index]])) {
@@ -519,6 +511,9 @@ frq.value <- function(index, x, df.val, weights, as.prc = FALSE) {
       valstring <- "<NA>"
     } else {
       if (as.prc) frqs <- sprintf("%.2f", 100 * frqs / sum(frqs))
+      if (length(frqs) > min(c(length(df.val[[index]]), max.len))) {
+        frqs <- frqs[1:min(c(length(df.val[[index]]), max.len))]
+      }
       valstring <- paste(frqs, collapse = "<br>")
     }
   }
